@@ -5,7 +5,7 @@ import wda
 import random
 
 global img
-global point1, point2,device
+global point1, point2
 
 def screen_shot(device_type,devices):
     if device_type == 'android':
@@ -60,8 +60,7 @@ def get_iamge():
     screen_shot('android',None)
     crop()
 
-def element_click(Prop,Value):
-    devices = device
+def element_click(devices,Prop,Value):
     if Prop=='xpath' or Prop=='XPath':
         devices.xpath(Value).click()
     else:
@@ -70,8 +69,7 @@ def element_click(Prop,Value):
         c=a+Prop+b
         eval(c)
 
-def element_is_exist(Prop,Value):
-    devices = device
+def element_is_exist(devices,Prop,Value):
     if Prop=='xpath' or Prop=='XPath':
         d=devices.xpath(Value).exists
     else:
@@ -93,8 +91,7 @@ def run_if(key,value):
         if key=='True':
             eval(value)
 
-def send_keys(Prop,Value,msg):
-    devices = device
+def send_keys(devices,Prop,Value,msg):
     if Prop=='xpath' or Prop=='XPath':
         devices.xpath(Value).click()
     else:
